# level 6

What to do with so much information?
Only some of it is actually useful.
The information you seek may be at the end
Of information that has a SECRET at the beginning.
And the way forward may be hidden as well.
If you find this hard to "man"-age, you might
Consider looking at "grep".
